@@ -4,9 +4,9 @@ from oscar.core.application import OscarConfig
 
 
 class OscarElasticSearchConfig(OscarConfig):
-    label = 'oscar_elasticsearch'
-    name = 'oscar_elasticsearch'
-    verbose_name = _('Elasticsearch')
+    label = "oscar_elasticsearch"
+    name = "oscar_elasticsearch"
+    verbose_name = _("Elasticsearch")
 
     def ready(self):
         from .signal_handlers import register_signal_handlers
