@@ -90,7 +90,7 @@ if is_model_registered("catalogue", "Product"):
             return upcs
 
         def attrs(self):
-            values = self.attribute_values.all().select_related("attribute")
+            values = self.get_attribute_values().select_related("attribute")
             result = {}
             for value in values:
                 try:
@@ -108,7 +108,12 @@ if is_model_registered("catalogue", "Product"):
 
             if self.is_parent:
                 for child in ProductProxy.objects.filter(parent=self):
-                    result = merge_dicts(result, child.attrs())
+                    result = merge_dicts(
+                        result,
+                        child.attrs(),
+                        multivalue=True,
+                        deduplicate_iterables=True,
+                    )
 
             return self.process_attributes(result)
 
@@ -120,10 +125,10 @@ if is_model_registered("catalogue", "Product"):
             return self.get_product_class().name
 
         def category_id(self):
-            return self.categories.values_list("id", flat=True)
+            return self.get_categories().values_list("id", flat=True)
 
         def category_name(self):
-            return list(self.categories.values_list("name", flat=True))
+            return list(self.get_categories().values_list("name", flat=True))
 
         @classmethod
         def get_indexed_objects(cls):
@@ -177,7 +182,6 @@ if is_model_registered("catalogue", "Product"):
                 [
                     index.FilterField("price_currency"),
                     index.SearchField("partner_sku"),
-                    index.SearchField("price_excl_tax"),
                     index.FilterField("partner"),
                     index.FilterField("num_in_stock"),
                 ],
